@@ -73,6 +73,17 @@ sub type {
 
 ##############################################
 
+=head2 perl_ref
+
+  perl_ref($any)
+
+returns ref
+
+=cut
+*perl_ref = *type;
+
+##############################################
+
 =head2 contains
 
   contains($haystack, $needle)
